getChangePoints: Coordinate profiles crossing points

View source: R/graphicsFuns.R

getChangePointsR Documentation

Coordinate profiles crossing points

Description

Obtain the points where the coordinate profile extrema functions cross the threshold

Usage

getChangePoints(threshold, Design = NULL, allRes)

Arguments

threshold

if not null plots the level

Design

a d dimensional design corresponding to the points

allRes

list containing the list res which contains the computed minima and maxima. The object returned by the function getAllMaxMin.

Value

returns a list containing two lists with d components where

  • alwaysEx: each component is a numerical vector indicating the points x_i where inf_{x^{-i}}f(x) > threshold;

  • neverEx: each component is a numerical vector indicating the points x_i where sup_{x^{-i}}f(x) < threshold.

Author(s)

Dario Azzimonti


profExtrema documentation built on July 21, 2026, 5:09 p.m.