getMin: Coordinate profile inf function

View source: R/getMaxNumOpt.R

getMinR Documentation

Coordinate profile inf function

Description

Compute coordinate profile inf functions

Usage

getMin(x, f, fprime, coord, d, options = NULL)

Arguments

x

one dimensional point where the function is to be evaluated

f

function to be optimized (takes a vector y of dimension d and returns a real number)

fprime

derivative of f (same format)

coord

integer selecting the dimension that is fixed, the other ones are optimized over

d

dimension of the input for f

options

a list containing the options to be passed to optim:

  • par: contains the starting point (a point in dimension d-1)

  • method: is the string denoting the chosen method for the optimization (see optim for details)

  • lower: the lower bounds for the optimization domain (see optim for details)

  • upper: the upper bounds for the optimization domain (see optim for details)

Value

a real value corresponding to min_{x_1,\dots, x_{coord-1},x_{coord+1}, \dots, x_d} f(x_1,\dots,x_d)

Author(s)

Dario Azzimonti


profExtrema documentation built on July 21, 2026, 5:09 p.m.