grad_mean_Delta_T: Gradient of the mean function of difference process

View source: R/bound_functions.R

grad_mean_Delta_TR Documentation

Gradient of the mean function of difference process

Description

The function grad_mean_Delta_T computes the gradient for the mean function of the difference process Z_x - \widetilde{Z}_x at x.

Usage

grad_mean_Delta_T(x, kmModel, simupoints, T.mat, F.mat)

Arguments

x

a matrix r x d containing the r points where the function is to be computed.

kmModel

the km model of the Gaussian process Z.

simupoints

the matrix l x d containing the pilot points G.

T.mat

the upper triangular factor of the Choleski decomposition of the covariance matrix of rbind(kmModel@X,simupoints)

F.mat

the evaluation of the trend function at rbind(kmModel@X,simupoints), see model.matrix.

Value

the value of the gradient for the mean function at x for the difference process Z^\Delta = Z_x - \widetilde{Z}_x.

Author(s)

Dario Azzimonti


profExtrema documentation built on July 21, 2026, 5:09 p.m.