View source: R/plotBivariateProfiles.R
| plotBivariateProfiles | R Documentation |
Plot bivariate profiles, for dimension up to 6.
plotBivariateProfiles(
bivProf,
allPsi,
Design = NULL,
threshold = NULL,
whichIQR = NULL,
plot_options = NULL,
...
)
bivProf |
list returned by |
allPsi |
a list containing the matrices Psi (dim |
Design |
a matrix of dimension |
threshold |
if not |
whichIQR |
which quantiles to use for the inter-quantile range plot. If |
plot_options |
list as returned by |
... |
additional parameters to be passed to the plot function |
plots the 2d maps of the profile sup and inf of the function for each Psi in allPsi. If threshold is not NULL also contours the threshold level.
Dario Azzimonti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.