| plotOneBivProfile | R Documentation |
Plots the bivariate profiles stored in allRes for each Psi in allPsi.
plotOneBivProfile(
allRes,
allPsi,
Design = NULL,
threshold = NULL,
trueEvals = NULL,
main_addendum = "",
...
)
allRes |
list containing the list |
allPsi |
a list containing the matrices Psi (dim |
Design |
a matrix of dimension |
threshold |
if not |
trueEvals |
if not |
main_addendum |
additional string to add to image title. Default is empty string. |
... |
additional parameters to be passed to the plot function |
plots the 2d maps of the profile sup and inf in allRes for each Psi in allPsi. If threshold is not NULL also contours the threshold level.
Dario Azzimonti
plotBivariateProfiles
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.