plot_univariate_profiles_UQ: Univariate profile extrema with UQ

View source: R/plot_univariate_profiles_UQ.R

plot_univariate_profiles_UQR Documentation

Univariate profile extrema with UQ

Description

Function to plot the univariate profile extrema functions with UQ

Usage

plot_univariate_profiles_UQ(
  objectUQ,
  plot_options,
  nsims,
  threshold,
  nameFile = "prof_UQ",
  quantiles_uq = c(0.05, 0.95),
  profMean = NULL,
  typeProf = "approx"
)

Arguments

objectUQ

an object returned by coordProf_UQ or the object saved in obj$res_UQ, if obj is the object returned by coordinateProfiles.

plot_options

a list containing the same elements as the one passed to coordinateProfiles

nsims

number of simulations

threshold

threshold of interest

nameFile

the central name of the plot file

quantiles_uq

a vector containing the quantiles to be computed

profMean

the profile coordinate extrema functions for the mean. It is saved in obj$profMean_full or obj$profMean_approx if obj is an object returned by coordinateProfiles.

typeProf

a string to choose with type of profile extrema for simulations to plot

  • "approx": plots only the approximate profile extrema for simulations

  • "full": plots only the full profile extrema for simulations

  • "both": plots both the approximate and full profile extrema for simulations

Value

Plots either to the default graphical device or to pdf (according to the options passed in plot_options)


profExtrema documentation built on July 21, 2026, 5:09 p.m.