profExtrema-package: profExtrema: Compute and Visualize Profile Extrema Functions

profExtrema-packageR Documentation

profExtrema: Compute and Visualize Profile Extrema Functions

Description

Computes profile extrema functions for arbitrary functions. If the function is expensive-to-evaluate it computes profile extrema by emulating the function with a Gaussian process (using package 'DiceKriging'). In this case uncertainty quantification on the profile extrema can also be computed. The different plotting functions for profile extrema give the user a tool to better locate excursion sets.

Author(s)

Maintainer: Dario Azzimonti dario.azzimonti@gmail.com (ORCID) [copyright holder]

Authors:

See Also

Useful links:


profExtrema documentation built on July 21, 2026, 5:09 p.m.