prof_mean_var_Delta: Profile extrema for the mean and variance functions of...

View source: R/bound_functions.R

prof_mean_var_DeltaR Documentation

Profile extrema for the mean and variance functions of difference process

Description

The function prof_mean_var_Delta computes the profile extrema functions for the mean and variance functions of the difference process Z_x - \widetilde{Z}_x at x.

Usage

prof_mean_var_Delta(
  kmModel,
  simupoints,
  allPsi = NULL,
  options_full_sims = NULL,
  options_approx = NULL,
  F.mat = NULL,
  T.mat = NULL
)

Arguments

kmModel

the km model of the Gaussian process Z.

simupoints

the matrix l x d containing the pilot points G.

allPsi

optional list of matrices (dim pxd) for which to compute the profile extrema. If NULL coordinate profiles are computed.

options_full_sims

an optional list of options for getAllMaxMin(or approxProfileExtrema if allPsi not NULL). If NULL the full computations are not excuted. NOTE: this computations might be very expensive!

options_approx

an optional list of options for approxMaxMin (or approxProfileExtrema if allPsi not NULL).

F.mat

the evaluation of the trend function at rbind(kmModel@X,simupoints), see model.matrix, if NULL it is computed.

T.mat

the upper triangular factor of the Choleski decomposition of the covariance matrix of rbind(kmModel@X,simupoints), if NULL it is computed.

Value

the profile extrema functions at options_approx$design for the mean and variance function of the difference process Z^\Delta = Z_x - \widetilde{Z}_x.

Author(s)

Dario Azzimonti


profExtrema documentation built on July 21, 2026, 5:09 p.m.