View source: R/bound_functions.R
| grad_mean_Delta_T | R Documentation |
The function grad_mean_Delta_T computes the gradient for the mean function of the difference process Z_x - \widetilde{Z}_x at x.
grad_mean_Delta_T(x, kmModel, simupoints, T.mat, F.mat)
x |
a matrix |
kmModel |
the km model of the Gaussian process |
simupoints |
the matrix |
T.mat |
the upper triangular factor of the Choleski decomposition of the covariance matrix of |
F.mat |
the evaluation of the trend function at |
the value of the gradient for the mean function at x for the difference process Z^\Delta = Z_x - \widetilde{Z}_x.
Dario Azzimonti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.