View source: R/plot_univariate_profiles_UQ.R
| plot_univariate_profiles_UQ | R Documentation |
Function to plot the univariate profile extrema functions with UQ
plot_univariate_profiles_UQ(
objectUQ,
plot_options,
nsims,
threshold,
nameFile = "prof_UQ",
quantiles_uq = c(0.05, 0.95),
profMean = NULL,
typeProf = "approx"
)
objectUQ |
an object returned by coordProf_UQ or the object saved in |
plot_options |
a list containing the same elements as the one passed to coordinateProfiles |
nsims |
number of simulations |
threshold |
threshold of interest |
nameFile |
the central name of the plot file |
quantiles_uq |
a vector containing the quantiles to be computed |
profMean |
the profile coordinate extrema functions for the mean. It is saved in |
typeProf |
a string to choose with type of profile extrema for simulations to plot
|
Plots either to the default graphical device or to pdf (according to the options passed in plot_options)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.