Function to plot the univariate profile extrema functions with UQ
plot_univariate_profiles_UQ(
objectUQ,
plot_options,
nsims,
threshold,
nameFile = "prof_UQ",
quantiles_uq = c(0.05, 0.95),
profMean = NULL,
typeProf = "approx"
)Plots either to the default graphical device or to pdf (according to the options passed in plot_options)
an object returned by coordProf_UQ or the object saved in obj$res_UQ, if obj is the object returned by coordinateProfiles.
a list containing the same elements as the one passed to coordinateProfiles
number of simulations
threshold of interest
the central name of the plot file
a vector containing the quantiles to be computed
the profile coordinate extrema functions for the mean. It is saved in obj$profMean_full or obj$profMean_approx if obj is an object returned by coordinateProfiles.
a string to choose with type of profile extrema for simulations to plot
"approx": plots only the approximate profile extrema for simulations
"full": plots only the full profile extrema for simulations
"both": plots both the approximate and full profile extrema for simulations