| profExtrema-package | R Documentation |
Computes profile extrema functions for arbitrary functions. If the function is expensive-to-evaluate it computes profile extrema by emulating the function with a Gaussian process (using package 'DiceKriging'). In this case uncertainty quantification on the profile extrema can also be computed. The different plotting functions for profile extrema give the user a tool to better locate excursion sets.
Maintainer: Dario Azzimonti dario.azzimonti@gmail.com (ORCID) [copyright holder]
Authors:
Dario Azzimonti dario.azzimonti@gmail.com (ORCID) [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.