View source: R/bound_functions.R
| prof_mean_var_Delta | R Documentation |
The function prof_mean_var_Delta computes the profile extrema functions for the mean and variance functions of the difference process Z_x - \widetilde{Z}_x at x.
prof_mean_var_Delta(
kmModel,
simupoints,
allPsi = NULL,
options_full_sims = NULL,
options_approx = NULL,
F.mat = NULL,
T.mat = NULL
)
kmModel |
the km model of the Gaussian process |
simupoints |
the matrix |
allPsi |
optional list of matrices (dim |
options_full_sims |
an optional list of options for getAllMaxMin(or approxProfileExtrema if |
options_approx |
an optional list of options for approxMaxMin (or approxProfileExtrema if |
F.mat |
the evaluation of the trend function at |
T.mat |
the upper triangular factor of the Choleski decomposition of the covariance matrix of |
the profile extrema functions at options_approx$design for the mean and variance function of the difference process Z^\Delta = Z_x - \widetilde{Z}_x.
Dario Azzimonti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.